==> com.liferay.exportimport.service-3.2.2-sources.jar: com/liferay/exportimport/lifecycle/CacheExportImportLifecycleListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.exportimport.lifecycle;

import com.liferay.exportimport.kernel.lar.PortletDataContext;
import com.liferay.exportimport.kernel.lifecycle.BaseExportImportLifecycleListener;
import com.liferay.exportimport.kernel.lifecycle.ExportImportLifecycleListener;
import com.liferay.portal.security.permission.PermissionCacheUtil;
import com.liferay.portal.servlet.filters.cache.CacheUtil;

import org.osgi.service.component.annotations.Component;

/**
 * @author Mate Thurzo
 */
@Component(immediate = true, service = ExportImportLifecycleListener.class)
public class CacheExportImportLifecycleListener
	extends BaseExportImportLifecycleListener {

	@Override
	public boolean isParallel() {
		return false;
	}

	protected void clearCache() {
		CacheUtil.clearCache();
		PermissionCacheUtil.clearCache();
	}

	@Override
	protected void onLayoutImportProcessFinished(
		PortletDataContext portletDataContext) {

		clearCache();
	}

	@Override
	protected void onPortletImportProcessFinished(
		PortletDataContext portletDataContext) {

		clearCache();
	}

}

==> com.liferay.exportimport.service-4.1.10-sources.jar: com/liferay/exportimport/lifecycle/CacheExportImportLifecycleListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.exportimport.lifecycle;

import aQute.bnd.annotation.ProviderType;

import com.liferay.exportimport.kernel.lar.PortletDataContext;
import com.liferay.exportimport.kernel.lifecycle.BaseExportImportLifecycleListener;
import com.liferay.portal.security.permission.PermissionCacheUtil;
import com.liferay.portal.servlet.filters.cache.CacheUtil;

/**
 * @author     Mate Thurzo
 * @deprecated As of Judson (7.1.x)
 */
@Deprecated
@ProviderType
public class CacheExportImportLifecycleListener
	extends BaseExportImportLifecycleListener {

	@Override
	public boolean isParallel() {
		return false;
	}

	protected void clearCache() {
		CacheUtil.clearCache();
		PermissionCacheUtil.clearCache();
	}

	@Override
	protected void onLayoutImportProcessFinished(
		PortletDataContext portletDataContext) {

		clearCache();
	}

	@Override
	protected void onPortletImportProcessFinished(
		PortletDataContext portletDataContext) {

		clearCache();
	}

}
